==> haskell-executable-path-0.0.3.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 executable-path
version:              0.0.3.1
visibility:           public
id:                   executable-path-0.0.3.1-Gi8UsVQRFScIwLNgvGtMvt
key:                  executable-path-0.0.3.1-Gi8UsVQRFScIwLNgvGtMvt
license:              LicenseRef-PublicDomain
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".

category:             System
abi:                  3679816757db553ea6af5c93d6cdafa0
exposed:              True
exposed-modules:      System.Environment.Executable
hidden-modules:       System.Environment.Executable.Linux
import-dirs:          /usr/lib/ghc-9.0.1/site-local/executable-path-0.0.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/executable-path-0.0.3.1
hs-libraries:         HSexecutable-path-0.0.3.1-Gi8UsVQRFScIwLNgvGtMvt
depends:
    base-4.15.0.0 directory-1.3.6.1 filepath-1.4.2.1 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-executable-path/html/executable-path.haddock

haddock-html:         /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-executable-path-0.0.3.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 executable-path
version:              0.0.3.1
visibility:           public
id:                   executable-path-0.0.3.1-AWiOm0iMK03AvVPZm1VkN7
key:                  executable-path-0.0.3.1-AWiOm0iMK03AvVPZm1VkN7
license:              LicenseRef-PublicDomain
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".

category:             System
abi:                  f22e3a76178dca13a8d9ca67c062e89f
exposed:              True
exposed-modules:      System.Environment.Executable
hidden-modules:       System.Environment.Executable.Linux
import-dirs:          /usr/lib/ghc-9.0.2/site-local/executable-path-0.0.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/executable-path-0.0.3.1
hs-libraries:         HSexecutable-path-0.0.3.1-AWiOm0iMK03AvVPZm1VkN7
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-executable-path/html/executable-path.haddock

haddock-html:         /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
